RequestBuilder class

Assembles an http.BaseRequest from all the FlutterApiCraft configuration objects.

This class is used internally and is not intended to be called directly by package consumers.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({required String baseUrl, required String path, required ApiType method, required Map<String, String> headers, ApiBody? body, ApiParams? params, ApiAuthorization? authorization, ApiCookies? cookies}) Future<BaseRequest>
Builds and returns the correct http.BaseRequest subtype: