clearCookies method
Clears cookies for domain, or clears the entire jar when domain
is null.
Implementation
void clearCookies([String? domain]) {
if (domain != null) {
_jar.remove(domain);
} else {
_jar.clear();
}
}
Clears cookies for domain, or clears the entire jar when domain
is null.
void clearCookies([String? domain]) {
if (domain != null) {
_jar.remove(domain);
} else {
_jar.clear();
}
}