disableCookiePersistence property
When true, cookies received in this response are not stored in the jar.
Implementation
final bool disableCookiePersistence;
When true, cookies received in this response are not stored in the jar.
final bool disableCookiePersistence;