enableCookieJar property
When true, the package automatically stores cookies from Set-Cookie
response headers and re-sends them as Cookie headers on subsequent
requests to the same domain.
Implementation
final bool enableCookieJar;
When true, the package automatically stores cookies from Set-Cookie
response headers and re-sends them as Cookie headers on subsequent
requests to the same domain.
final bool enableCookieJar;