errorMessageKey property
Key used to read the error message from the response body Map.
Defaults to "message".
Implementation
final String? errorMessageKey;
Key used to read the error message from the response body Map.
Defaults to "message".
final String? errorMessageKey;