successMessageKey property
Key used to read the success message from the response body Map.
Defaults to "message".
Implementation
final String? successMessageKey;
Key used to read the success message from the response body Map.
Defaults to "message".
final String? successMessageKey;