errorMessage property
Human-readable error message extracted from the response body or the caught exception.
null on success.
Implementation
final String? errorMessage;
Human-readable error message extracted from the response body or the caught exception.
null on success.
final String? errorMessage;