NavigationAction enum
Navigation action to take after a successful API response.
Values
- none → const NavigationAction
-
Do nothing after the request.
- pop → const NavigationAction
-
Call
Get.back()— pop the current screen. - popUntil → const NavigationAction
-
Call
Get.until(...)— pop until a named route. - pushNamed → const NavigationAction
-
Call
Get.toNamed(...)— push a new named route. - pushReplacement → const NavigationAction
-
Call
Get.offNamed(...)— replace the current screen. - pushAndRemoveUntil → const NavigationAction
-
Call
Get.offAllNamed(...)— clear stack and push a named route. - offAll → const NavigationAction
-
Call
Get.offAll(...)— clear stack and push a widget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NavigationAction> - A constant List of the values in this enum, in order of their declaration.