RawBodyContentType enum
Content-type variants for ApiBodyType.raw bodies.
Values
- json → const RawBodyContentType
-
application/json— auto-encodes Maps and Lists. - text → const RawBodyContentType
-
text/plain - xml → const RawBodyContentType
-
application/xml - html → const RawBodyContentType
-
text/html - javascript → const RawBodyContentType
-
application/javascript
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RawBodyContentType> - A constant List of the values in this enum, in order of their declaration.