AuthorizationBuilder class
Converts an ApiAuthorization config into HTTP header entries and/or URL query-parameter additions.
This class is used internally by RequestBuilder and is not intended to be used directly by package consumers.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildHeaders(
ApiAuthorization? auth) → Map< String, String> -
Returns the HTTP headers derived from
auth. -
buildQueryParams(
ApiAuthorization? auth) → Map< String, String> -
Returns URL query parameters derived from
auth.