enableCookieJar property

bool enableCookieJar
final

When true, the package automatically stores cookies from Set-Cookie response headers and re-sends them as Cookie headers on subsequent requests to the same domain.

Implementation

final bool enableCookieJar;